DELIVERY_TYPES = {
    "PACKAGE_DELIVERY": {
        "code": 10,
        "value": "Forward"
    },
    "SEND": {
        "code": 10,
        "value": "Package Delivery"
    },
    "CASH_COLLECTION": {
        "code": 15,
        "value": "Cash Collection"
    },
    "RTO": {
        "code": 20,
        "value": "Return to Origin"
    },
    "CRP": {
        "code": 25,
        "value": "Customer Return Pickup"
    },
    "EXCHANGE": {
        "code": 30,
        "value": "Exchange"
    }
}
