# Copyright 2020 by BOSTA. All Rights Reserved.
#
# Permission to use, copy, modify, and distribute this software and its
# documentation for any purpose and without fee is hereby granted,
# provided that the above copyright notice appear in all copies and that
# both that copyright notice and this permission notice appear in
# supporting documentation, and that the name of bosta
# not be used in advertising or publicity pertaining to distribution
# of the software without specific, written prior permission.
# BOSTA DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
# ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
# BOSTA BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
# ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER
# IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
# OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

"""
Bosta package for Python. Based on PEP 282 and comments thereto in
comp.lang.python.

Copyright (C) 2020. All Rights Reserved.

To use, simply 'import bostaSDK'!
"""

from .delivery import *
from .pickup import *
from .utils import *

__author__ = "sohila bogdady <sdk@bosta.co>"
__status__ = "development"
__version__ = "0.9"
__date__ = "07 Sep 2020"
__name__ = "Bosta"
